declare module 'content/routes.js' {
  /**
   * Defines the available `views` that can be used to set up routes.
   * Each `Template` has different configuration options
   */
  type Template = 
    | 'markdown'

  /**
   * Defines the shared options for a route
   */
  type SharedRouteDefinition = {
    id: string
    stylesheetUrls: string[]
    template: Template
  }

  /**
   * Defines a content-based route
   */
  type ContentfulRouteDefintion = SharedRouteDefinition & {
    content: string
  }

  /**
   * Defines the config for a route using the `markdown` {@link Template}
   */
  type MarkdownDefinition = ContentfulRouteDefintion & {
    template: 'markdown'
  }

  /**
   * Defines all available route definitions
   */
  type RouteDefinition =
    | MarkdownDefinition

  /**
   * Defines the collection of routes the app uses
   */
  type RouteCollection = { [key: string]: RouteDefinition }

  /**
   * The routes the app uses
   */
  const routes: RouteCollection

  /**
   * Defines an entry in the app header.
   * Optionally recursive by defining children instead of path.
   */
  type HeaderEntry = {
    displayName: string
  } & ({
    path: string
  } | {
    children: HeaderEntry[]
  })

  /**
   * The header the app uses.
   * If not present, the header will not show.
   */
  const header: HeaderEntry[]
}
